# Whispercppy

Python bindings for [whisper.cpp](https://github.com/ggerganov/whisper.cpp)

Most of the binding code is taken with tiny modifications from [aarnphm/whispercpp](https://github.com/aarnphm/whispercpp).
